# py3_sg

## Python3 SCSI generic library  

This is a fork of [crypto-universe/py_sg](https://github.com/crypto-universe/py_sg).  


## Install

Dependencies:
- `<Python.h>` header file. (`python3-dev` or `python3-devel`)

```shell
sudo python3 -m pip install py3_sg
```


## How to install manually

```shell
git clone https://github.com/7aman/py3_sg.git
cd py3_sg
python3 setup.py build
```
If .so library is compiled, install:
```shell
sudo python3 setup.py install
```
